Struct pallet_vesting::Module [−][src]
Vesting module declaration.
Implementations
impl<T: Config + 'static> Module<T>[src]
pub fn vesting<K: EncodeLike<T::AccountId>>(
key: K
) -> Option<VestingInfo<<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance, T::BlockNumber>>[src]
key: K
) -> Option<VestingInfo<<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance, T::BlockNumber>>
Information regarding the vesting of a given account.
impl<T: Config> Module<T>[src]
Can also be called using Call.
pub fn vested_transfer(
origin: T::Origin,
target: <T::Lookup as StaticLookup>::Source,
schedule: VestingInfo<<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance, T::BlockNumber>
) -> DispatchResult[src]
origin: T::Origin,
target: <T::Lookup as StaticLookup>::Source,
schedule: VestingInfo<<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance, T::BlockNumber>
) -> DispatchResult
Create a vested transfer.
The dispatch origin for this call must be Signed.
target: The account that should be transferred the vested funds.amount: The amount of funds to transfer and will be vested.schedule: The vesting schedule attached to the transfer.
Emits VestingCreated.
O(1).- DbWeight: 3 Reads, 3 Writes
- Reads: Vesting Storage, Balances Locks, Target Account, [Sender Account]
- Writes: Vesting Storage, Balances Locks, Target Account, [Sender Account]
NOTE: Calling this function will bypass origin filters.
pub fn force_vested_transfer(
origin: T::Origin,
source: <T::Lookup as StaticLookup>::Source,
target: <T::Lookup as StaticLookup>::Source,
schedule: VestingInfo<<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance, T::BlockNumber>
) -> DispatchResult[src]
origin: T::Origin,
source: <T::Lookup as StaticLookup>::Source,
target: <T::Lookup as StaticLookup>::Source,
schedule: VestingInfo<<<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance, T::BlockNumber>
) -> DispatchResult
Force a vested transfer.
The dispatch origin for this call must be Root.
source: The account whose funds should be transferred.target: The account that should be transferred the vested funds.amount: The amount of funds to transfer and will be vested.schedule: The vesting schedule attached to the transfer.
Emits VestingCreated.
O(1).- DbWeight: 4 Reads, 4 Writes
- Reads: Vesting Storage, Balances Locks, Target Account, Source Account
- Writes: Vesting Storage, Balances Locks, Target Account, Source Account
NOTE: Calling this function will bypass origin filters.